]> cloudbase.mooo.com Git - irmp.git/blobdiff - irsnd.c
corrected modulation frequency for denon protocol in irsnd.c, corrected #if for toggl...
[irmp.git] / irsnd.c
diff --git a/irsnd.c b/irsnd.c
index 3cbe8d5ff2ff6775337d2a87ba93c80a8208cd3f..da0996086486018b4d35fff6163d696a3f7988bb 100644 (file)
--- a/irsnd.c
+++ b/irsnd.c
@@ -331,7 +331,7 @@ irsnd_send_data (IRMP_DATA * irmp_data_p, uint8_t do_wait)
 #if IRSND_SUPPORT_RC5_PROTOCOL == 1\r
     static uint8_t  toggle_bit_rc5;\r
 #endif\r
-#if IRSND_SUPPORT_RC5_PROTOCOL == 1\r
+#if IRSND_SUPPORT_RC6_PROTOCOL == 1 || IRSND_SUPPORT_RC6A_PROTOCOL == 1\r
     static uint8_t  toggle_bit_rc6;\r
 #endif\r
     uint16_t        address;\r
@@ -1006,7 +1006,7 @@ irsnd_ISR (void)
                         n_auto_repetitions          = DENON_FRAMES;                                 // 2 frames, 2nd with inverted command\r
                         auto_repetition_pause_len   = DENON_AUTO_REPETITION_PAUSE_LEN;              // 65 ms pause after 1st frame\r
                         repeat_frame_pause_len      = DENON_FRAME_REPEAT_PAUSE_LEN;\r
-                        irsnd_set_freq (IRSND_FREQ_38_KHZ);                                         // in theory 32kHz, in practice 38kHz\r
+                        irsnd_set_freq (IRSND_FREQ_36_KHZ);                                         // in theory 32kHz, in practice 36kHz is better\r
                         break;\r
                     }\r
 #endif\r